#[non_exhaustive]pub enum AccessSource {
Team(String),
OrgOwner(String),
OrgMember(String),
}Expand description
Where access that is not a direct role comes from.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Team(String)
Membership of a team with access to the repository (the team’s name).
OrgOwner(String)
Being an owner of the organisation (its login).
OrgMember(String)
The permission every member of the organisation has on its repositories (the organisation’s login).